public inbox for pbs-devel@lists.proxmox.com
 help / color / mirror / Atom feed
From: Dominik Csapak <d.csapak@proxmox.com>
To: pbs-devel@lists.proxmox.com
Subject: [pbs-devel] [PATCH proxmox-backup 1/4] api2/types/userid: make Userid updatable
Date: Fri,  5 Mar 2021 09:45:29 +0100	[thread overview]
Message-ID: <20210305084532.19550-2-d.csapak@proxmox.com> (raw)
In-Reply-To: <20210305084532.19550-1-d.csapak@proxmox.com>

Signed-off-by: Dominik Csapak <d.csapak@proxmox.com>
---
 src/api2/types/userid.rs | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/api2/types/userid.rs b/src/api2/types/userid.rs
index 7c73e69f..3b47ccdf 100644
--- a/src/api2/types/userid.rs
+++ b/src/api2/types/userid.rs
@@ -30,7 +30,7 @@ use lazy_static::lazy_static;
 use serde::{Deserialize, Serialize};
 
 use proxmox::api::api;
-use proxmox::api::schema::{ApiStringFormat, Schema, StringSchema};
+use proxmox::api::schema::{ApiStringFormat, Schema, StringSchema, Updatable};
 use proxmox::const_regex;
 
 // we only allow a limited set of characters
@@ -393,7 +393,7 @@ impl<'a> TryFrom<&'a str> for &'a TokennameRef {
 }
 
 /// A complete user id consisting of a user name and a realm
 #[derive(Clone, Debug, PartialEq, Eq, Hash)]
 pub struct Userid {
     data: String,
     name_len: usize,
@@ -393,7 +393,7 @@ impl<'a> TryFrom<&'a str> for &'a TokennameRef {
 
 /// A complete user id consisting of a user name and a realm
-#[derive(Clone, Debug, PartialEq, Eq, Hash)]
+#[derive(Clone, Debug, PartialEq, Eq, Hash, Updatable)]
 pub struct Userid {
     data: String,
-- 
2.20.1





  reply	other threads:[~2021-03-05  8:46 UTC|newest]

Thread overview: 9+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2021-03-05  8:45 [pbs-devel] [PATCH proxmox-backup 0/4] add notify-user to tape backup/restore Dominik Csapak
2021-03-05  8:45 ` Dominik Csapak [this message]
2021-03-05 12:02   ` [pbs-devel] [PATCH proxmox-backup 1/4] api2/types/userid: make Userid updatable Dietmar Maurer
2021-03-05  8:45 ` [pbs-devel] [PATCH proxmox-backup 2/4] config/tape_job: add notify-user config to tape jobs Dominik Csapak
2021-03-05 12:02   ` [pbs-devel] applied: " Dietmar Maurer
2021-03-05  8:45 ` [pbs-devel] [PATCH proxmox-backup 3/4] api2/tape: add notify_user to backup(-jobs) and restore api calls Dominik Csapak
2021-03-05 12:03   ` Dietmar Maurer
2021-03-05  8:45 ` [pbs-devel] [PATCH proxmox-backup 4/4] ui: tape: add notify-user fields Dominik Csapak
2021-03-05 12:02   ` [pbs-devel] applied: " Dietmar Maurer

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20210305084532.19550-2-d.csapak@proxmox.com \
    --to=d.csapak@proxmox.com \
    --cc=pbs-devel@lists.proxmox.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
Service provided by Proxmox Server Solutions GmbH | Privacy | Legal